Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Downloader ¶
type Downloader interface {
// Download connects to gnames database and downloads canonical forms of
// names from sources that are considered to be 'reliable'.
// Then it downloads generic names from the IRMNG project.
// These files will be first preprocessed, than the data will be converted
// to the output for gnfinder.
Download(dat *data.Data) error
// Close cleans up database connections.
Close() error
}
type Preproc ¶
type Preproc struct {
// contains filtered or unexported fields
}
func (*Preproc) Preprocess ¶
Click to show internal directories.
Click to hide internal directories.